@@ -281,7 +281,7 @@ def show(
     cmap="gray",
     grid=False,
     save_path=None,
-    text_sz=10,
+    text_sz=None,
     df=None,
     pts=None,
     conns=None,
@@ -371,6 +371,7 @@ def show(
         bb_colors = [None] * len(bbs) if bb_colors is None else bb_colors
         img = C(img) if len(img.shape) == 2 else img
         [rect(img, tuple(bb), c=bb_colors[ix], th=th) for ix, bb in enumerate(bbs)]
+    text_sz = text_sz if text_sz else (max(sz) * 3 // 5)
     if texts is not None:
         if hasattr(texts, "shape"):
             if isinstance(texts, torch.Tensor):
@@ -395,13 +396,7 @@ def show(
             pts = (pts * np.array([[w, h]])).astype(np.uint16).tolist()
         ax.scatter(*zip(*pts), c=kwargs.pop("pts_color", "red"))
     if conns is not None:
-        conn_colors = kwargs.pop("conn_colors", ["cyan"] * len(conns))
-        for ix in range(len(conns)):
-            if len(conns[ix]) == 2:
-                start_ix, end_ix = conns[ix]
-                meta = 1
-            else:
-                start_ix, end_ix, meta = conns[ix]
+        for start_ix, end_ix, meta in conns:
             _x, _y = bbs[start_ix].xc, bbs[start_ix].yc
             _X, _Y = bbs[end_ix].xc, bbs[end_ix].yc
             _dx, _dy = _X - _x, _Y - _y
@@ -412,7 +407,7 @@ def show(
                 _jitter(_dx),
                 _jitter(_dy),
                 length_includes_head=True,
-                color=conn_colors[ix],
+                color="cyan",
                 head_width=4,
                 head_length=4,
                 width=meta * 2,
@@ -666,6 +661,46 @@ def lzip(*x):
     return list(zip(*x))
 
 
+# def to_absolute(input, shape):
+#     if isinstance(shape, np.ndarray) and shape.ndim >= 2:
+#         shape = shape.shape[:2]
+#     h, w = shape
+#     if isinstance(input, BB):
+#         return input.absolute((h, w))
+#     elif isinstance(input, pd.DataFrame):
+
+#         def _round(x):
+#             return np.round(x.values.astype(np.double)).astype(np.uint16)
+
+#         df = input.copy()
+#         df["x"] = _round(df.x * w)
+#         df["X"] = _round(df.X * w)
+#         df["y"] = _round(df.y * h)
+#         df["Y"] = _round(df.Y * h)
+#         return df
+#     elif isinstance(input, list):
+#         bbs = bbfy(input)
+#         return [bb.absolute((h, w)) for bb in bbs]
+
+
+# def to_relative(input, shape):
+#     if isinstance(shape, np.ndarray) and shape.ndim >= 2:
+#         shape = shape.shape[:2]
+#     h, w = shape
+#     if isinstance(input, BB):
+#         return input.relative((h, w))
+#     elif isinstance(input, pd.DataFrame):
+#         df = input.copy()
+#         df["x"] = df.x / w
+#         df["X"] = df.X / w
+#         df["y"] = df.y / h
+#         df["Y"] = df.Y / h
+#         return df
+#     elif isinstance(input, list):
+#         bbs = bbfy(input)
+#         return [bb.relative((h, w)) for bb in bbs]
+
+
 from fastcore.basics import patch_to
 
 
